<?php
/*
 * This file is a part of Mibew Messenger.
 *
 * Copyright 2005-2015 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

namespace JustBlackBird\HandlebarsHelpers\Date;

use Handlebars\Context;
use Handlebars\Helper as HelperInterface;
use Handlebars\Template;

/**
 * Format date using PHP's strftime format string.
 *
 * Usage:
 * ```handlebars
 *   {{formatDate time format}}
 * ```
 *
 * Arguments:
 *  - "time": Can be either an integer timestamp or an instance of \DateTime
 *    class.
 *  - "format": Format string. See
 *    {@link http://php.net/manual/en/function.strftime.php} for details about
 *    placeholders.
 *
 * @author Dmitriy Simushev <simushevds@gmail.com>
 */
class FormatDateHelper implements HelperInterface
{
    /**
     * {@inheritdoc}
     */
    public function execute(Template $template, Context $context, $args, $source)
    {
        $parsed_args = $template->parseArguments($args);
        if (count($parsed_args) != 2) {
            throw new \InvalidArgumentException(
                '"formatDate" helper expects exactly two arguments.'
            );
        }

        $raw_time = $context->get($parsed_args[0]);
        if ($raw_time instanceof \DateTime) {
            $timestamp = $raw_time->getTimestamp();
        } else {
            $timestamp = intval($raw_time);
        }
        $format = $context->get($parsed_args[1]);

        return strftime($format, $timestamp);
    }
}
