<?php
/*
 * This file is a part of Mibew Messenger.
 *
 * Copyright 2005-2015 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

namespace JustBlackBird\HandlebarsHelpers\Layout;

use Handlebars\Context;
use Handlebars\Helper as HelperInterface;
use Handlebars\Template;

/**
 * A helper for overriding content of a block.
 *
 * One or more "override" blocks must be wrapped with
 * {@link \JustBlackBird\HandlebarsHelpers\Layout\ExtendsHelper} helper.
 *
 * Usage:
 * ```handlebars
 *   {{#override blockName}}
 *     Overridden content of the block.
 *   {{/override}}
 * ```
 *
 * Arguments:
 *  - blockName: Name of the block which should be overridden.
 *
 * @author Dmitriy Simushev <simushevds@gmail.com>
 */
class OverrideHelper extends AbstractBlockHelper implements HelperInterface
{
    /**
     * {@inheritdoc}
     */
    public function execute(Template $template, Context $context, $args, $source)
    {
        // Get block name
        $parsed_args = $template->parseArguments($args);
        if (count($parsed_args) != 1) {
            throw new \InvalidArgumentException(
                '"override" helper expects exactly one argument.'
            );
        }
        $block_name = $context->get(array_shift($parsed_args));

        // We need to provide unlimited inheritence level. Rendering is started
        // from the deepest level template. If the content is in the block
        // storage it is related with the deepest level template. Thus we do not
        // need to override it.
        if (!$this->blocksStorage->has($block_name)) {
            $this->blocksStorage->set($block_name, $template->render($context));
        }
    }
}
