<?php
/*
 * This file is a part of Mibew Messenger.
 *
 * Copyright 2005-2015 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

namespace JustBlackBird\HandlebarsHelpers\String;

use Handlebars\Context;
use Handlebars\Helper as HelperInterface;
use Handlebars\Template;

/**
 * Repeats content specified number of times.
 *
 * Usage:
 * ```handlebars
 *   {{#repeat times}}content to repeat{{/repeat}}
 * ```
 *
 * Arguments:
 *  - "times": How many times content must be repeated. This value must be
 *    greater than or equal to 0 otherwise an exception will be thrown.
 *
 * @author Dmitriy Simushev <simushevds@gmail.com>
 */
class RepeatHelper implements HelperInterface
{
    /**
     * {@inheritdoc}
     */
    public function execute(Template $template, Context $context, $args, $source)
    {
        $parsed_args = $template->parseArguments($args);
        if (count($parsed_args) != 1) {
            throw new \InvalidArgumentException(
                '"repeat" helper expects exactly one argument.'
            );
        }

        $times = intval($context->get($parsed_args[0]));
        if ($times < 0) {
            throw new \InvalidArgumentException(
                'The first argument of "repeat" helper has to be greater than or equal to 0.'
            );
        }
        $string = $template->render($context);

        return str_repeat($string, $times);
    }
}
