<?php
/*
 * This file is a part of Mibew Messenger.
 *
 * Copyright 2005-2015 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

namespace JustBlackBird\HandlebarsHelpers\Tests\String;

use JustBlackBird\HandlebarsHelpers\String\RepeatHelper;

/**
 * Test class for "repeat" helper.
 *
 * @author Dmitriy Simushev <simushevds@gmail.com>
 */
class RepeatHelperTest extends \PHPUnit_Framework_TestCase
{
    /**
     * Tests that strings are repeated properly.
     *
     * @dataProvider repeatProvider
     */
    public function testRepeat($string, $times, $result)
    {
        $helpers = new \Handlebars\Helpers(array('repeat' => new RepeatHelper()));
        $engine = new \Handlebars\Handlebars(array('helpers' => $helpers));

        $this->assertEquals(
            $engine->render(
                '{{#repeat times}}{{str}}{{/repeat}}',
                array('times' => $times, 'str' => $string)
            ),
            $result
        );
    }

    /**
     * A data provider for testRepeat method.
     */
    public function repeatProvider()
    {
        return array(
            array('+', 0, ''),
            array('+', 3, '+++'),
            array('', 3, ''),
        );
    }

    /**
     * Tests that exception is thrown if wrong number of arguments is used.
     *
     * @expectedException InvalidArgumentException
     * @dataProvider wrongArgumentsSetProvider
     */
    public function testArgumentsCount($template)
    {
        $helpers = new \Handlebars\Helpers(array('repeat' => new RepeatHelper()));
        $engine = new \Handlebars\Handlebars(array('helpers' => $helpers));

        $engine->render($template, array());
    }

    /**
     * A data provider for testArgumentsCount method.
     */
    public function wrongArgumentsSetProvider()
    {
        return array(
            // Not enough arguments
            array('{{#repeat}}{{/repeat}}'),
            // Too much arguments
            array('{{#repeat 10 "ANOTHER ARG"}}{{/repeat}}'),
        );
    }

    /**
     * Tests that exception is thrown if arguments are invalid.
     *
     * @expectedException InvalidArgumentException
     */
    public function testInvalidArguments()
    {
        $helpers = new \Handlebars\Helpers(array('repeat' => new RepeatHelper()));
        $engine = new \Handlebars\Handlebars(array('helpers' => $helpers));

        $engine->render('{{#repeat -10}}+{{/repeat}}', array());
    }
}
