<?php
/*
 * This file is a part of Mibew Messenger.
 *
 * Copyright 2005-2015 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

namespace JustBlackBird\HandlebarsHelpers\Tests\String;

use JustBlackBird\HandlebarsHelpers\String\ReplaceHelper;

/**
 * Test class for "replace" helper.
 *
 * @author Dmitriy Simushev <simushevds@gmail.com>
 */
class ReplaceHelperTest extends \PHPUnit_Framework_TestCase
{
    /**
     * Tests that strings are repeated properly.
     *
     * @dataProvider replaceProvider
     */
    public function testReplace($string, $search, $replacement, $result)
    {
        $helpers = new \Handlebars\Helpers(array('replace' => new ReplaceHelper()));
        $engine = new \Handlebars\Handlebars(array('helpers' => $helpers));

        $this->assertEquals(
            $engine->render(
                '{{#replace search replacement}}{{str}}{{/replace}}',
                array('str' => $string, 'search' => $search, 'replacement' => $replacement)
            ),
            $result
        );
    }

    /**
     * A data provider for testReplace method.
     */
    public function replaceProvider()
    {
        return array(
            array('abcd', 'b', '', 'acd'),
            array('abcd', 'xyz', '', 'abcd'),
            array('abcd', '', 'asd', 'abcd'),
        );
    }

    /**
     * Tests that exception is thrown if wrong number of arguments is used.
     *
     * @expectedException InvalidArgumentException
     * @dataProvider wrongArgumentsSetProvider
     */
    public function testArgumentsCount($template)
    {
        $helpers = new \Handlebars\Helpers(array('replace' => new ReplaceHelper()));
        $engine = new \Handlebars\Handlebars(array('helpers' => $helpers));

        $engine->render($template, array());
    }

    /**
     * A data provider for testArgumentsCount method.
     */
    public function wrongArgumentsSetProvider()
    {
        return array(
            // Not enough arguments
            array('{{#replace}}str{{/replace}}'),
            array('{{#replace "serach"}}str{{/replace}}'),
            // Too much arguments
            array('{{#replace "search" "replacement" "asd"}}str{{/replace}}'),
        );
    }
}
