<?php
/*
 * This file is a part of Mibew Messenger.
 *
 * Copyright 2005-2015 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
namespace UAParser;

use UAParser\Result\OperatingSystem;

class OperatingSystemParser extends AbstractParser
{
    /**
     * Attempts to see if the user agent matches an operating system regex from regexes.php
     *
     * @param string $userAgent a user agent string to test
     * @return OperatingSystem
     */
    public function parseOperatingSystem($userAgent)
    {
        $os = new OperatingSystem();

        list($regex, $matches) = $this->tryMatch($this->regexes['os_parsers'], $userAgent);

        if ($matches) {
            $os->family = $this->replaceString($regex, 'os_replacement', $matches[1]);
            $os->major = $this->replaceString($regex, 'os_v1_replacement', $matches[2]);
            $os->minor = $this->replaceString($regex, 'os_v2_replacement', $matches[3]);
            $os->patch = $this->replaceString($regex, 'os_v3_replacement', $matches[4]);
            $os->patchMinor = $this->replaceString($regex, 'os_v4_replacement', $matches[5]);
        }

        return $os;
    }
}
