<?php
/*
 * This file is a part of Mibew Messenger.
 *
 * Copyright 2005-2015 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
namespace UAParser\Util\Logfile;

use PHPUnit_Framework_TestCase as AbstractTestCase;
use UAParser\Util\Logfile\ReaderInterface;

abstract class AbstractReaderTest extends AbstractTestCase
{
    /** @var ReaderInterface */
    protected $reader;

    /** @var string */
    protected $line;

    /** @var string */
    protected $userAgentString;

    /** @var string */
    protected $exampleLogFile;

    public function testTestEmptyLine()
    {
        $this->assertFalse($this->reader->test(''));
    }

    public function testTestRealLine()
    {
        $this->assertTrue($this->reader->test($this->line));
    }

    public function testReadEmptyLine()
    {
        $this->setExpectedException(
            'UAParser\Exception\ReaderException',
            'Cannot extract user agent string from line "invalid"'
        );
        $this->reader->read('invalid');
    }

    public function testReadRealLine()
    {
        $this->assertSame($this->userAgentString, $this->reader->read($this->line));
    }

    public function testReadingFile()
    {
        if (!$this->exampleLogFile) {
            $this->markTestSkipped('Try with your own log file');
        }

        foreach (file($this->exampleLogFile) as $line) {
            $this->assertTrue($this->reader->test($line));
            $this->assertGreaterThanOrEqual(1, strlen($this->reader->read($line)));
        }
    }
}
