<?php
/*
 * This file is a part of Mibew Messenger.
 *
 * Copyright 2005-2015 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

namespace Handlebars\Loader;

use Handlebars\Loader;

/**
 * Handlebars Template array Loader implementation.
 *
 * @category  Xamin
 * @package   Handlebars
 * @author    fzerorubigd <fzerorubigd@gmail.com>
 * @copyright 2014 (c) f0ruD
 * @license   MIT <http://opensource.org/licenses/MIT>
 * @version   Release: @package_version@
 * @link      http://xamin.ir *
 */
class ArrayLoader implements Loader
{
    private $_templates;

    /**
     * Create a new loader with associative array style
     *
     * @param array $templates the templates to load
     */
    public function __construct(array $templates = array())
    {
        $this->_templates = $templates;
    }

    /**
     * Add a template to list
     *
     * @param string $name     template name
     * @param string $template the template
     *
     * @return void
     */
    public function addTemplate($name, $template)
    {
        $this->_templates[$name] = $template;
    }

    /**
     * Load a Template by name.
     *
     * @param string $name template name to load
     *
     * @throws \RuntimeException
     * @return String
     */
    public function load($name)
    {
        if (isset($this->_templates[$name])) {
            return $this->_templates[$name];
        }
        throw new \RuntimeException(
            "Can not find the $name template"
        );
    }
}